# flet-ads

[![pypi](https://img.shields.io/pypi/v/flet-ads.svg)](https://pypi.python.org/pypi/flet-ads)
[![downloads](https://static.pepy.tech/badge/flet-ads/month)](https://pepy.tech/project/flet-ads)
[![python](https://img.shields.io/badge/python-%3E%3D3.10-%2334D058)](https://pypi.org/project/flet-ads)
[![docstring coverage](https://docs.flet.dev/assets/badges/docs-coverage/flet-ads.svg)](https://docs.flet.dev/assets/badges/docs-coverage/flet-ads.svg)
[![license](https://img.shields.io/badge/License-Apache_2.0-green.svg)](https://github.com/flet-dev/flet/blob/main/sdk/python/packages/flet-ads/LICENSE)

Display Google Ads in [Flet](https://flet.dev) apps.

It is based on the [google_mobile_ads](https://pub.dev/packages/google_mobile_ads) Flutter package.

## Documentation

Detailed documentation to this package can be found [here](https://docs.flet.dev/ads/).

## Platform Support

| Platform | Windows | macOS | Linux | iOS | Android | Web |
|----------|---------|-------|-------|-----|---------|-----|
| Supported|    ❌    |   ❌   |   ❌   |  ✅  |    ✅    |  ❌  |

## Usage

### Installation

To install the `flet-ads` package and add it to your project dependencies:

- Using `uv`:
    ```bash
    uv add flet-ads
    ```

- Using `pip`:
    ```bash
    pip install flet-ads
    ```
    After this, you will have to manually add this package to your `requirements.txt` or `pyproject.toml`.

### Examples

For examples, see [these](https://github.com/flet-dev/flet/tree/main/sdk/python/examples/controls/ads).
